@@ -1,7 +1,7 @@
 package Complete::Fish::Gen::FromPerinciCmdLine;
 
-our $DATE = '2016-10-22'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2016-10-27'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -19,11 +19,18 @@ $SPEC{gen_fish_complete_from_perinci_cmdline_script} = {
     v => 1.1,
     summary => 'Dump Perinci::CmdLine script '.
         'and generate fish completion from it',
+    description => <<'_',
+
+This routine generate `complete` fish command for each option, allowing fish to
+display the options in a different color.
+
+_
     args => {
         filename => {
             schema => 'filename*',
             req => 1,
             pos => 0,
+            cmdline_aliases => {f=>{}},
         },
         cmdname => {
             summary => 'Command name (by default will be extracted from filename)',
@@ -33,6 +40,10 @@ $SPEC{gen_fish_complete_from_perinci_cmdline_script} = {
             summary => 'Completer name (in case different from cmdname)',
             schema => 'str*',
         },
+        skip_detect => {
+            schema => ['bool', is=>1],
+            cmdline_aliases => {D=>{}},
+        },
     },
     result => {
         schema => 'str*',
@@ -45,7 +56,9 @@ sub gen_fish_complete_from_perinci_cmdline_script {
 
     require Perinci::CmdLine::Dump;
     my $dump_res = Perinci::CmdLine::Dump::dump_perinci_cmdline_script(
-        filename => $filename);
+        filename => $filename,
+        skip_detect => $args{skip_detect},
+    );
     return [500, "Can't dump script: $dump_res->[0] - $dump_res->[1]"]
         unless $dump_res->[0] == 200;
 
@@ -79,9 +92,32 @@ sub gen_fish_complete_from_perinci_cmdline_script {
                 "$gengls_res->[0] - $gengls_res->[1]"]
         unless $gengls_res->[0] == 200;
     my $glspec = $gengls_res->[2];
-
     $glspec->{'<>'} = sub{};
 
+    require Perinci::Sub::To::CLIDocData;
+    my $genclidocdata_res = Perinci::Sub::To::CLIDocData::gen_cli_doc_data_from_meta(
+        common_opts => $cli->{common_opts},
+        ggls_res => $gengls_res,
+        meta => $meta,
+        meta_is_normalized => 1,
+        per_arg_json => $cli->{per_arg_json},
+        per_arg_yaml => $cli->{per_arg_yaml},
+    );
+    return [500, "Can't generate CLI doc data: ".
+                "$genclidocdata_res->[0] - $genclidocdata_res->[1]"]
+        unless $genclidocdata_res->[0] == 200;
+    my $clidocdata = $genclidocdata_res->[2];
+
+    my $opt_desc = {};
+    for my $k (sort keys %{$clidocdata->{opts}}) {
+        my $v = $clidocdata->{opts}{$k};
+        next unless $v->{summary};
+        my @o = $k =~ /--?(\S+)/g;
+        for my $o (@o) {
+            $opt_desc->{$o} = $v->{summary};
+        }
+    }
+
     my $cmdname = $args{cmdname};
     if (!$cmdname) {
         ($cmdname = $filename) =~ s!.+/!!;
@@ -91,6 +127,7 @@ sub gen_fish_complete_from_perinci_cmdline_script {
     require Complete::Fish::Gen::FromGetoptLong;
     Complete::Fish::Gen::FromGetoptLong::gen_fish_complete_from_getopt_long_spec(
         spec => $glspec,
+        opt_desc => $opt_desc,
         cmdname => $cmdname,
         compname => $compname,
     );
@@ -111,7 +148,7 @@ Complete::Fish::Gen::FromPerinciCmdLine - Dump Perinci::CmdLine script and gener
 
 =head1 VERSION
 
-This document describes version 0.002 of Complete::Fish::Gen::FromPerinciCmdLine (from Perl distribution Complete-Fish-Gen-FromPerinciCmdLine), released on 2016-10-22.
+This document describes version 0.003 of Complete::Fish::Gen::FromPerinciCmdLine (from Perl distribution Complete-Fish-Gen-FromPerinciCmdLine), released on 2016-10-27.
 
 =head1 SYNOPSIS
 
@@ -122,6 +159,9 @@ This document describes version 0.002 of Complete::Fish::Gen::FromPerinciCmdLine
 
 Dump Perinci::CmdLine script and generate fish completion from it.
 
+This routine generate C<complete> fish command for each option, allowing fish to
+display the options in a different color.
+
 This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
@@ -138,6 +178,8 @@ Completer name (in case different from cmdname).
 
 =item * B<filename>* => I<filename>
 
+=item * B<skip_detect> => I<bool>
+
 =back
 
 Returns an enveloped result (an array).
